==> kvirc_3.2.0.orig.tar.gz: kvirc-3.2.0/src/modules/options/optw_userlist.h <==
#ifndef _OPTW_USERLIST_H_
#define _OPTW_USERLIST_H_

//
//   File : optw_userlist.h
//   Creation date : Sat Mar 02 2002 12:09:19 CEST by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2002 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_optionswidget.h"
#include <qcombobox.h>

#define KVI_OPTIONS_WIDGET_ICON_KviUserListLookOptionsWidget KVI_SMALLICON_USERLIST
#define KVI_OPTIONS_WIDGET_NAME_KviUserListLookOptionsWidget __tr_no_lookup("Userlist")
#define KVI_OPTIONS_WIDGET_PARENT_KviUserListLookOptionsWidget KviThemeOptionsWidget


class KviUserListLookOptionsWidget : public KviOptionsWidget
{
	Q_OBJECT
public:
	KviUserListLookOptionsWidget(QWidget * parent);
	~KviUserListLookOptionsWidget();
protected:
	QComboBox * m_pGridTypeCombo;
public:
	virtual void commit();
};

#define KVI_OPTIONS_WIDGET_ICON_KviUserListFeaturesOptionsWidget KVI_SMALLICON_USERLIST
#define KVI_OPTIONS_WIDGET_NAME_KviUserListFeaturesOptionsWidget __tr_no_lookup("Userlist")
#define KVI_OPTIONS_WIDGET_PARENT_KviUserListFeaturesOptionsWidget KviInterfaceFeaturesOptionsWidget

class KviUserListFeaturesOptionsWidget : public KviOptionsWidget
{
	Q_OBJECT
public:
	KviUserListFeaturesOptionsWidget(QWidget * parent);
	~KviUserListFeaturesOptionsWidget();
};

#endif //!_OPTW_USERLIST_H_

==> kvirc_3.2.4.orig.tar.gz: kvirc-3.2.4/src/modules/options/optw_userlist.h <==
#ifndef _OPTW_USERLIST_H_
#define _OPTW_USERLIST_H_

//
//   File : optw_userlist.h
//   Creation date : Sat Mar 02 2002 12:09:19 CEST by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2002-2006 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_optionswidget.h"
#include <qcombobox.h>

#define KVI_OPTIONS_WIDGET_ICON_KviUserListLookOptionsWidget KVI_SMALLICON_USERLIST
#define KVI_OPTIONS_WIDGET_NAME_KviUserListLookOptionsWidget __tr2qs_no_lookup("Userlist")
#define KVI_OPTIONS_WIDGET_KEYWORDS_KviUserListLookOptionsWidget __tr2qs_no_lookup("theme,userlist,channel")
#define KVI_OPTIONS_WIDGET_GROUP_KviUserListLookOptionsWidget "theme"

class KviUserListLookOptionsWidget : public KviOptionsWidget
{
	Q_OBJECT
public:
	KviUserListLookOptionsWidget(QWidget * parent);
	~KviUserListLookOptionsWidget();
protected:
	QComboBox * m_pGridTypeCombo;
	QComboBox* m_pHorisontalAlign;
	QComboBox* m_pVerticalAlign;
public:
	virtual void commit();
};

#define KVI_OPTIONS_WIDGET_ICON_KviUserListFeaturesOptionsWidget KVI_SMALLICON_USERLIST
#define KVI_OPTIONS_WIDGET_NAME_KviUserListFeaturesOptionsWidget __tr2qs_no_lookup("Userlist")
#define KVI_OPTIONS_WIDGET_PARENT_KviUserListFeaturesOptionsWidget KviInterfaceFeaturesOptionsWidget
#define KVI_OPTIONS_WIDGET_KEYWORDS_KviUserListFeaturesOptionsWidget __tr2qs_no_lookup("userlist,channel")

class KviUserListFeaturesOptionsWidget : public KviOptionsWidget
{
	Q_OBJECT
public:
	KviUserListFeaturesOptionsWidget(QWidget * parent);
	~KviUserListFeaturesOptionsWidget();
};

#endif //!_OPTW_USERLIST_H_
